@@ -46,6 +46,8 @@ import SciMLOperators:
 
 @reexport using SciMLOperators
 
+using SciMLPublic: @public
+
 function __solve end
 function __init end
 
@@ -930,4 +932,9 @@ export Clocks, TimeDomain, is_discrete_time_domain, isclock, issolverstepclock,
 
 export ODEAliasSpecifier, LinearAliasSpecifier
 
+# Public traits
+
+@public has_init
+@public has_step
+
 end
