@@ -299,8 +299,23 @@ allows_late_binding_tstops(alg::AbstractODEAlgorithm) = false
 """
     $(TYPEDSIGNATURES)
 
-Trait declaration for whether the optimization algorithm supports the `init` interface. 
+Trait declaration for whether the optimization algorithm supports the `init` interface.
 
 Deprecated as this is not an optimization-specific idea and should use the traits for general caching.
 """
 supports_opt_cache_interface(alg) = false
+
+"""
+    $(TYPEDSIGNATURES)
+
+Trait for specifying whether the passed algorithm supports `init`. Any `init`ed object can `solve!`.
+"""
+has_init(a) = false
+
+"""
+    $(TYPEDSIGNATURES)
+
+Trait for specifying whether the passed algorithm supports `step!`, specifying a more direct control over the internal solver process.
+See https://docs.sciml.ai/SciMLBase/stable/interfaces/Init_Solve/#init-and-the-Iterator-Interface for more details.
+"""
+has_step(a) = false
